import{u as n}from"./router.94ccd1ff.js";import{r as o,w as s}from"./runnerData.3191407d.js";import"./vue-router.6b399b0b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="20b2e8d4-d283-4403-a65d-15acf0a10f75",t._sentryDebugIdIdentifier="sentry-dbid-20b2e8d4-d283-4403-a65d-15acf0a10f75")}catch{}})();async function i(t){const e=n(),r=await fetch(`/_pages/${t}`,{headers:e.authHeaders});if(r.status===404)return null;if(!r.ok)throw new Error(await r.text());const{form:a}=await r.json();return a?o(a):null}async function c(){const t=n(),e=await fetch("/_workspace",{headers:t.authHeaders});if(e.status!=200)return s({});const r=await e.json();return s(r)}export{i as f,c as g};
//# sourceMappingURL=api.84842e32.js.map
