import{O as d}from"./router.94ccd1ff.js";import{d as l,Z as c,o as u,eu as i,b as a,w as n,u as o,ar as s,cR as f,cQ as b}from"./vue-router.6b399b0b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0392e557-f91e-4a93-9b56-b2c5cc7f1027",e._sentryDebugIdIdentifier="sentry-dbid-0392e557-f91e-4a93-9b56-b2c5cc7f1027")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return c(async()=>{await new d().logoutCallback()}),(t,r)=>(u(),i("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.79815770.js.map
