import{u as k}from"./router.94ccd1ff.js";import{d as w,L as _,K as u,q as g,o as r,eu as v,b as s,w as h,u as e,c as p,ew as m,R as K}from"./vue-router.6b399b0b.js";import{K as T,_ as R,W as I,P,b as S}from"./WorkflowView.76187bab.js";import{P as V}from"./api.821769a1.js";import{A as c,T as x}from"./TabPane.dfa9c37c.js";import"./Card.ddda3ab5.js";import"./fetch.2c48c3fe.js";import"./workspaces.77c090b1.js";import"./asyncComputed.c7982027.js";import"./runnerData.3191407d.js";import"./url.2f4a4260.js";import"./record.f5201a57.js";import"./scripts.b1aac29c.js";import"./metadata.961ac5fc.js";import"./PhCheckCircle.vue.a5f11655.js";import"./PhKanban.vue.3064199b.js";import"./PhScroll.vue.094a2d8c.js";import"./PhWebhooksLogo.vue.30aa7d79.js";import"./ant-design.3e244f71.js";import"./index.2e72b67b.js";import"./index.57cdc892.js";import"./index.2411222c.js";import"./index.84989af6.js";import"./CollapsePanel.c4d5ce40.js";import"./index.2dca7a14.js";import"./index.b8b86307.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.e6897781.js";import"./model.80eeed94.js";import"./validations.1ac27aba.js";import"./string.79d7b0e1.js";import"./PhArrowSquareOut.vue.efaf22f5.js";import"./index.38b2dea8.js";import"./Badge.b9eb592f.js";import"./index.80a69b0e.js";import"./uuid.2cda8c4d.js";import"./LoadingOutlined.b0d848ca.js";import"./DeleteOutlined.fcb2310c.js";import"./PhDownloadSimple.vue.1c2db1a3.js";import"./utils.f9575e62.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="ec600ae5-3c1c-4007-a16f-bf3f0152ea01",t._sentryDebugIdIdentifier="sentry-dbid-ec600ae5-3c1c-4007-a16f-bf3f0152ea01")}catch{}})();const W={class:"threads-view"},A=w({__name:"Threads",setup(t){const a=k().authHeaders,f=new V(a),i=new P(a),b=new S(a),y=new _(u.array(u.string()),"kanban-selected-stages"),o=g("kanban");return(B,l)=>(r(),v("div",W,[s(e(x),{activeKey:o.value,"onUpdate:activeKey":l[0]||(l[0]=d=>o.value=d)},{default:h(()=>[s(e(c),{key:"kanban",tab:"Kanban View"}),s(e(c),{key:"table",tab:"Table View"}),s(e(c),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(r(),p(T,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(b)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(r(),p(R,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(r(),p(I,{key:2,"kanban-repository":e(i),"workflow-api":e(f)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=K(A,[["__scopeId","data-v-60c67f27"]]);export{ge as default};
//# sourceMappingURL=Threads.a47158ab.js.map
