import{C as d}from"./ContentLayout.a837d946.js";import{d as w,L as c,K as l,q as g,o as a,c as n,w as u,b as i,u as o,ew as s}from"./vue-router.6b399b0b.js";import{K as _,_ as v,W as K,E,a as R}from"./WorkflowView.76187bab.js";import{E as T}from"./api.821769a1.js";import{A as p,T as V}from"./TabPane.dfa9c37c.js";import"./fetch.2c48c3fe.js";import"./workspaces.77c090b1.js";import"./asyncComputed.c7982027.js";import"./runnerData.3191407d.js";import"./url.2f4a4260.js";import"./record.f5201a57.js";import"./scripts.b1aac29c.js";import"./metadata.961ac5fc.js";import"./PhCheckCircle.vue.a5f11655.js";import"./PhKanban.vue.3064199b.js";import"./PhScroll.vue.094a2d8c.js";import"./PhWebhooksLogo.vue.30aa7d79.js";import"./ant-design.3e244f71.js";import"./index.2e72b67b.js";import"./index.57cdc892.js";import"./index.2411222c.js";import"./index.84989af6.js";import"./CollapsePanel.c4d5ce40.js";import"./index.2dca7a14.js";import"./index.b8b86307.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.e6897781.js";import"./model.80eeed94.js";import"./validations.1ac27aba.js";import"./string.79d7b0e1.js";import"./PhArrowSquareOut.vue.efaf22f5.js";import"./index.38b2dea8.js";import"./Badge.b9eb592f.js";import"./index.80a69b0e.js";import"./Card.ddda3ab5.js";import"./uuid.2cda8c4d.js";import"./LoadingOutlined.b0d848ca.js";import"./DeleteOutlined.fcb2310c.js";import"./PhDownloadSimple.vue.1c2db1a3.js";import"./utils.f9575e62.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="80e03675-1216-445e-bba9-4183c490b3c7",e._sentryDebugIdIdentifier="sentry-dbid-80e03675-1216-445e-bba9-4183c490b3c7")}catch{}})();const ko=w({__name:"WorkflowThreads",setup(e){const t=new E,m=new R,f=new c(l.array(l.string()),"kanban-selected-stages"),k=new T,r=g("kanban");return(W,b)=>(a(),n(d,{"full-width":""},{default:u(()=>[i(o(V),{activeKey:r.value,"onUpdate:activeKey":b[0]||(b[0]=y=>r.value=y)},{default:u(()=>[i(o(p),{key:"kanban",tab:"Kanban View"}),i(o(p),{key:"table",tab:"Table View"}),i(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),r.value==="kanban"?(a(),n(_,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(f),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),r.value==="table"?(a(),n(v,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),r.value==="workflow"?(a(),n(K,{key:2,"kanban-repository":o(t),"workflow-api":o(k)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{ko as default};
//# sourceMappingURL=WorkflowThreads.cab1b653.js.map
