import{eY as t,eZ as r}from"./vue-router.6b399b0b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="aac2bc59-cd8a-4ff1-92bf-6c063c551759",e._sentryDebugIdIdentifier="sentry-dbid-aac2bc59-cd8a-4ff1-92bf-6c063c551759")}catch{}})();function d(e,n){return t(1,arguments),r(e,Date.now(),n)}export{d as f};
//# sourceMappingURL=index.2411222c.js.map
