import{L as B}from"./Logo.f554efd3.js";import{d as x,eJ as A,r as w,u as e,o as s,c as i,bj as C,eu as m,b as a,w as t,ar as r,bG as d,a as f,cQ as N,eG as _,cw as D,Q as I,eE as L,fb as z,aD as g,ew as S,dB as R,R as V}from"./vue-router.6b399b0b.js";import{a as $}from"./asyncComputed.c7982027.js";import{G as E}from"./PhChats.vue.c013bdec.js";import{F as G}from"./PhSignOut.vue.66574882.js";import{C as T}from"./router.ab3f179a.js";import{a as k}from"./gateway.34f2a318.js";import{A as j}from"./index.2e72b67b.js";import{A as F}from"./index.ab218211.js";import{B as P,A as Q,b as q}from"./index.e61aa379.js";import{B as H}from"./BookOutlined.7993dbf1.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[o]="d85b69cd-0c9e-4e0f-9746-021bb010d33f",n._sentryDebugIdIdentifier="sentry-dbid-d85b69cd-0c9e-4e0f-9746-021bb010d33f")}catch{}})();const J={key:1,style:{display:"flex","align-items":"center",gap:"16px"}},M={style:{display:"flex","flex-direction":"column",gap:"10px"}},O={style:{display:"flex",gap:"5px"}},U=x({__name:"LoginBlock",setup(n){function o(b){const y=b.split("@")[0];return I.exports.kebabCase(y).toUpperCase().split("-").slice(0,2).map(u=>u[0]).join("")}const c=A(),{result:l,loading:p,refetch:h}=$(async()=>k.getAuthor());function v(){k.removeAuthor(),T.shutdown(),h(),c.push({name:"login"})}return(b,y)=>{const u=w("router-link");return e(p)?(s(),i(e(C),{key:0})):e(l)?(s(),m("div",J,[a(e(d),{class:"intercom-launcher",target:"_blank",type:"link",size:"small",style:{color:"#d14056",display:"flex","align-items":"center",gap:"6px"}},{icon:t(()=>[a(e(E),{size:18})]),default:t(()=>[r(" Support ")]),_:1}),a(e(D),{placement:"bottomRight"},{content:t(()=>[f("div",M,[a(e(N),{size:"small",type:"secondary"},{default:t(()=>[r(_(e(l).claims.email),1)]),_:1}),a(e(d),{type:"text",onClick:v},{default:t(()=>[f("div",O,[a(e(G),{size:"20"}),r(" Logout ")])]),_:1})])]),default:t(()=>[a(e(j),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[a(e(F),{shape:"square"},{default:t(()=>[r(_(o(e(l).claims.email)),1)]),_:1})]),_:1})]),_:1})])):(s(),i(e(d),{key:2},{default:t(()=>[a(u,{to:"/login"},{default:t(()=>[r("Login")]),_:1})]),_:1}))}}}),K={class:"extra"},W=x({__name:"Navbar",props:{breadcrumb:{}},setup(n){return(o,c)=>(s(),i(e(q),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[o.breadcrumb?(s(),i(e(P),{key:0,style:{margin:"0px 50px"}},{default:t(()=>[(s(!0),m(g,null,L(o.breadcrumb,(l,p)=>(s(),i(e(Q),{key:p},{default:t(()=>[a(e(z),{to:l.path},{default:t(()=>[r(_(l.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):S("",!0)]),title:t(()=>[a(B)]),extra:t(()=>[f("div",K,[a(e(d),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[a(e(H))]),default:t(()=>[o.$slots.default?R(o.$slots,"default",{key:0},void 0,!0):(s(),m(g,{key:1},[r("Docs")],64))]),_:3}),a(U)])]),_:3}))}});const ie=V(W,[["__scopeId","data-v-29235e83"]]);export{ie as N};
//# sourceMappingURL=Navbar.ad237c01.js.map
