import{g as c}from"./api.84842e32.js";import{_ as m}from"./Login.vue_vue_type_script_setup_true_lang.79c1592e.js";import{u}from"./router.94ccd1ff.js";import{a as d}from"./asyncComputed.c7982027.js";import{W as p}from"./WidgetsFrame.b6d30f3d.js";import{d as _,eJ as l,eC as y,u as r,o as b,c as g,w,ew as h,b as C,R as I}from"./vue-router.6b399b0b.js";import"./runnerData.3191407d.js";import"./url.2f4a4260.js";import"./CircularLoading.4ef662fa.js";import"./index.80a69b0e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="bf543f5a-1e5f-451f-b94d-db8a6298f3e9",e._sentryDebugIdIdentifier="sentry-dbid-bf543f5a-1e5f-451f-b94d-db8a6298f3e9")}catch{}})();const k=_({__name:"Login",setup(e){const t=l(),s=y(),{result:o}=d(c),f=u(),i=async()=>{await f.signUp();const{redirect:a,...n}=s.query;if(a){await t.push({path:a,query:n,params:s.params});return}t.push({name:"playerHome",query:n})};return(a,n)=>r(o)?(b(),g(p,{key:0,"main-color":r(o).mainColor,theme:r(o).theme,"font-family":r(o).fontFamily,class:"runner"},{default:w(()=>[C(m,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):h("",!0)}});const S=I(k,[["__scopeId","data-v-ae51cc13"]]);export{S as default};
//# sourceMappingURL=Login.f0c0caa9.js.map
