import{a6 as s,di as a}from"./vue-router.6b399b0b.js";import{g as d}from"./index.2d411136.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="56053b8d-1292-42c8-83f7-884379459f9c",e._sentryDebugIdIdentifier="sentry-dbid-56053b8d-1292-42c8-83f7-884379459f9c")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:c}=d(a),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.8d8a95b3.js.map
