import{a as g}from"./asyncComputed.c7982027.js";import{d as y,eC as _,Z as w,u as e,o as l,c as b,eu as C,b as a,w as o,cR as x,ar as p,cV as h,bG as I,a as k,eG as v}from"./vue-router.6b399b0b.js";import"./gateway.34f2a318.js";import"./index.c3b84c4d.js";import{O as B}from"./organization.c27666c7.js";import{C as f}from"./router.ab3f179a.js";import{L as D}from"./LoadingContainer.55b14629.js";import{A as N}from"./index.2dca7a14.js";import{C as z}from"./Card.ddda3ab5.js";import"./popupNotifcation.17b9c327.js";import"./record.f5201a57.js";import"./string.79d7b0e1.js";import"./TabPane.dfa9c37c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="a558f1ef-137e-46f2-9e0d-e1dfc23dd448",t._sentryDebugIdIdentifier="sentry-dbid-a558f1ef-137e-46f2-9e0d-e1dfc23dd448")}catch{}})();const M={key:1},A={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},J=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:c,result:u}=g(()=>B.get(s));w(()=>{location.search.includes("upgrade")&&f.showNewMessage("I want to upgrade my plan")});const m=()=>f.showNewMessage("I want to upgrade my plan");return(V,j)=>e(c)?(l(),b(D,{key:0})):(l(),C("div",M,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(x),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(N),{style:{"margin-top":"0"}}),a(e(z),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",A,v((d=(i=(r=e(u))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{J as default};
//# sourceMappingURL=Billing.29cb05cb.js.map
