import{O as r}from"./router.94ccd1ff.js";import{d as l,Z as c,o as i,eu as u,b as a,w as n,u as d,ar as o,cR as f,cQ as b}from"./vue-router.6b399b0b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1202db0a-9900-47ed-bd03-2305edc38cca",e._sentryDebugIdIdentifier="sentry-dbid-1202db0a-9900-47ed-bd03-2305edc38cca")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return c(async()=>{await new r().loginCallback()}),(t,s)=>(i(),u("div",null,[a(d(f),null,{default:n(()=>[o("You're authenticated")]),_:1}),a(d(b),null,{default:n(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.a1554d39.js.map
