import{R as o,r,o as i,c,h as p,T as d,i as u,P as _,C as f,M as l,s as g,j as s,k as y,l as b,m,n as v}from"./vue-router.6b399b0b.js";import{s as w,c as h,a}from"./router.94ccd1ff.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="cbca1e4f-64b4-4a22-8319-9e7b49912174",t._sentryDebugIdIdentifier="sentry-dbid-cbca1e4f-64b4-4a22-8319-9e7b49912174")}catch{}})();const I={};function k(t,e){const n=r("router-view");return i(),c(n,{style:{height:"100vh",width:"100%"}})}const A=o(I,[["render",k]]);class D{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const t=h(),e=p({render:()=>y(A)});d.init(),u(e,a),D.init(),e.use(a),e.use(t),e.use(_),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,b),s(e,m),s(e,v)})();
//# sourceMappingURL=player.5515d439.js.map
