import{P as d}from"./PlayerNavbar.e6889e3c.js";import{u as _,b as m}from"./router.94ccd1ff.js";import{d as l,eJ as f,eC as h,r as b,o as g,eu as y,b as s,u as a,a as v,R as w}from"./vue-router.6b399b0b.js";import"./metadata.961ac5fc.js";import"./PhCheckCircle.vue.a5f11655.js";import"./PhKanban.vue.3064199b.js";import"./PhScroll.vue.094a2d8c.js";import"./PhWebhooksLogo.vue.30aa7d79.js";import"./asyncComputed.c7982027.js";import"./PhSignOut.vue.66574882.js";import"./api.84842e32.js";import"./runnerData.3191407d.js";import"./url.2f4a4260.js";import"./index.ab218211.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="7cf9f894-fc68-477f-bc2c-90a1d524d8db",t._sentryDebugIdIdentifier="sentry-dbid-7cf9f894-fc68-477f-bc2c-90a1d524d8db")}catch{}})();const I={class:"main-container"},k={class:"content"},C=l({__name:"Main",setup(t){const e=f(),o=_(),c=h().path,i=({path:n})=>{e.push({path:`/${n}`})},u=()=>{e.push({name:"playerLogin"})};return m(()=>e.push({name:"playerLogin"})),(n,L)=>{var r;const p=b("router-view");return g(),y("div",I,[s(d,{"current-path":a(c),"user-email":(r=a(o).user)==null?void 0:r.claims.email,onNavigate:i,onLoginClick:u},null,8,["current-path","user-email"]),v("section",k,[s(p)])])}}});const j=w(C,[["__scopeId","data-v-c8854c08"]]);export{j as default};
//# sourceMappingURL=Main.2b663574.js.map
