import{B as d}from"./BookOutlined.7993dbf1.js";import{d as c,o as s,c as l,w as o,b,u as n,dB as f,eu as u,ar as i,aD as p,bG as y}from"./vue-router.6b399b0b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d3a142a7-c08c-4657-a9ad-bbcbe51fcbb5",t._sentryDebugIdIdentifier="sentry-dbid-d3a142a7-c08c-4657-a9ad-bbcbe51fcbb5")}catch{}})();const k=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),l(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:o(()=>[b(n(d))]),default:o(()=>[e.$slots.default?f(e.$slots,"default",{key:0}):(s(),u(p,{key:1},[i("Docs")],64))]),_:3},8,["href"])}}});export{k as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.e21048fc.js.map
