import{_ as c}from"./logo.084e5d7c.js";import{d,o as s,eu as t,ew as n,eA as _,eB as r,a as p,R as i}from"./vue-router.6b399b0b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6f1a9e0f-a238-48bc-b73b-70ee90ecd4f6",e._sentryDebugIdIdentifier="sentry-dbid-6f1a9e0f-a238-48bc-b73b-70ee90ecd4f6")}catch{}})();const f=e=>(_("data-v-ee47c447"),e=e(),r(),e),l={class:"logo"},u=f(()=>p("img",{class:"logo-img",src:c,alt:"Abstra cloud logo"},null,-1)),b={key:0},g=d({__name:"Logo",props:{hideText:{type:Boolean}},setup(e){return(o,a)=>(s(),t("div",l,[u,o.hideText?(s(),t("span",b,"Abstra")):n("",!0)]))}});const h=i(g,[["__scopeId","data-v-ee47c447"]]);export{h as L};
//# sourceMappingURL=Logo.f554efd3.js.map
