import{d as n,o as d,eu as s,a,dB as r,ey as c,R as l}from"./vue-router.6b399b0b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a4806b3d-dd92-445c-943e-2561ce45392c",e._sentryDebugIdIdentifier="sentry-dbid-a4806b3d-dd92-445c-943e-2561ce45392c")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(d(),s("div",_,[a("div",{class:c(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const f=l(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.a837d946.js.map
