import{g as _}from"./api.84842e32.js";import{W as g}from"./Watermark.9380ed47.js";import{i as h}from"./metadata.961ac5fc.js";import{a as k}from"./asyncComputed.c7982027.js";import{W as w}from"./WidgetsFrame.b6d30f3d.js";import{F as b}from"./PhArrowSquareOut.vue.efaf22f5.js";import{d as x,eJ as v,J as C,u as e,o as s,c as m,w as a,ew as D,b as n,cN as l,ar as f,eu as F,eE as I,cV as u,eF as V,eG as W,aD as N,R as T}from"./vue-router.6b399b0b.js";import"./index.ace58727.js";import{C as z}from"./Card.ddda3ab5.js";import"./router.94ccd1ff.js";import"./runnerData.3191407d.js";import"./url.2f4a4260.js";import"./PhCheckCircle.vue.a5f11655.js";import"./PhKanban.vue.3064199b.js";import"./PhScroll.vue.094a2d8c.js";import"./PhWebhooksLogo.vue.30aa7d79.js";import"./TabPane.dfa9c37c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="1451d643-9efc-44a1-a5aa-53b8cc404da1",o._sentryDebugIdIdentifier="sentry-dbid-1451d643-9efc-44a1-a5aa-53b8cc404da1")}catch{}})();const B=x({__name:"Home",setup(o){const i=v(),{result:t}=k(_),d=C(()=>{var r;return((r=t.value)==null?void 0:r.sidebar.filter(p=>p.id!=="home"))||[]}),y=r=>{i.push({path:`/${r}`})};return(r,p)=>e(t)?(s(),m(w,{key:0,class:"home-container","main-color":e(t).mainColor,theme:e(t).theme,"font-family":e(t).fontFamily},{default:a(()=>[n(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:a(()=>[d.value.length===0?(s(),m(e(l),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:a(()=>[f(" There are no forms available for you. ")]),_:1})):(s(!0),F(N,{key:1},I(d.value,c=>(s(),m(e(z),{key:c.id,class:"form-card",onClick:E=>y(c.path)},{default:a(()=>[n(e(u),{gap:"large",align:"center",justify:"space-between"},{default:a(()=>[(s(),m(V(e(h)(c.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),n(e(l),{style:{"font-size":"18px","font-weight":"500"}},{default:a(()=>[f(W(c.name),1)]),_:2},1024),n(e(b),{size:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}),n(g,{class:"watermark","page-id":"home"})]),_:1},8,["main-color","theme","font-family"])):D("",!0)}});const Y=T(B,[["__scopeId","data-v-c7d28f54"]]);export{Y as default};
//# sourceMappingURL=Home.ec885cfb.js.map
