import{L as k}from"./Logo.f554efd3.js";import{a as v}from"./asyncComputed.c7982027.js";import{d as A,eC as C,eJ as x,J as I,o as d,eu as N,b as n,w as t,u as e,c as _,ew as m,f1 as s,ar as a,eG as l,cR as B,cN as p,bG as D,a as T,cO as E,R}from"./vue-router.6b399b0b.js";import{g as V}from"./api.84842e32.js";import{C as G}from"./Card.ddda3ab5.js";import"./logo.084e5d7c.js";import"./router.94ccd1ff.js";import"./runnerData.3191407d.js";import"./url.2f4a4260.js";import"./TabPane.dfa9c37c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new j().stack;c&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[c]="951c1247-c0e6-403c-a5c3-43ec042db955",o._sentryDebugIdIdentifier="sentry-dbid-951c1247-c0e6-403c-a5c3-43ec042db955")}catch{}})();const L={class:"inner-content"},H={class:"card-content"},J=A({__name:"Error",setup(o){var y,b,h;const c=C(),f=x(),{result:u}=v(V),g=(h=(y=u.value)==null?void 0:y.name)!=null?h:(b=u.value)==null?void 0:b.brandName,r=I(()=>{const{status:i}=c.params;switch(i){case"404":return{status:i,title:s.translate("i18n_page_not_found"),message:s.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:i,title:s.translate("i18n_access_denied"),message:s.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:s.translate("i18n_internal_error"),message:s.translate("i18n_internal_error_message"),showAd:!1}}}),w=()=>{f.push({name:"playerHome"})};return(i,O)=>(d(),N("div",L,[n(e(B),null,{default:t(()=>[a(l(r.value.title),1)]),_:1}),n(e(p),{class:"message"},{default:t(()=>[a(l(r.value.message),1)]),_:1}),r.value.action?(d(),_(e(D),{key:0,type:"link",onClick:w},{default:t(()=>[a(l(r.value.action),1)]),_:1})):m("",!0),r.value.showAd?(d(),_(e(G),{key:1,bordered:!1,class:"card"},{default:t(()=>[T("div",H,[n(k,{style:{"margin-bottom":"10px"}}),n(e(p),null,{default:t(()=>[a("This page is part of "+l(e(g)?`the ${e(g)}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(u)?(d(),_(e(p),{key:0},{default:t(()=>[a("Automate your own processes by getting started "),n(e(E),{href:"https://abstra.io"},{default:t(()=>[a("here")]),_:1}),a(".")]),_:1})):m("",!0)])]),_:1})):m("",!0)]))}});const j=R(J,[["__scopeId","data-v-5f3771e3"]]);export{j as default};
//# sourceMappingURL=Error.03ecb507.js.map
