import{d as a,o,eu as c,b as s,u as d,bj as r,R as _}from"./vue-router.6b399b0b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="2c3759c9-1ac5-44cb-9e94-c984d6a3742c",e._sentryDebugIdIdentifier="sentry-dbid-2c3759c9-1ac5-44cb-9e94-c984d6a3742c")}catch{}})();const i={class:"centered"},u=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),c("div",i,[s(d(r))]))}});const p=_(u,[["__scopeId","data-v-1da18eee"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.55b14629.js.map
