import{L as D}from"./LoadingContainer.55b14629.js";import{S as h}from"./SaveButton.cddcaf82.js";import{C as x,W as A}from"./model.80eeed94.js";import{E as C}from"./api.821769a1.js";import{d as E,q as W,J as N,u as t,o,c as n,eu as _,ew as y,b as d,w as r,a as w,aD as B,eE as V,cQ as k,ar as f,eG as m,eF as G,cw as S,cV as F,R as L}from"./vue-router.6b399b0b.js";import{w as T}from"./metadata.961ac5fc.js";import{a as M}from"./asyncComputed.c7982027.js";import{A as q}from"./index.2e72b67b.js";import{A as I}from"./index.2dca7a14.js";import"./ExclamationCircleOutlined.0e03634b.js";import"./workspaces.77c090b1.js";import"./runnerData.3191407d.js";import"./url.2f4a4260.js";import"./record.f5201a57.js";import"./validations.1ac27aba.js";import"./string.79d7b0e1.js";import"./PhArrowSquareOut.vue.efaf22f5.js";import"./index.38b2dea8.js";import"./Badge.b9eb592f.js";import"./isNumeric.75337b1e.js";import"./index.80a69b0e.js";import"./Card.ddda3ab5.js";import"./TabPane.dfa9c37c.js";import"./uuid.2cda8c4d.js";import"./fetch.2c48c3fe.js";import"./PhCheckCircle.vue.a5f11655.js";import"./PhKanban.vue.3064199b.js";import"./PhScroll.vue.094a2d8c.js";import"./PhWebhooksLogo.vue.30aa7d79.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[i]="9bf1fa83-c033-46db-a73f-f359ee65c2af",s._sentryDebugIdIdentifier="sentry-dbid-9bf1fa83-c033-46db-a73f-f359ee65c2af")}catch{}})();const J={key:1,class:"workflow-editor"},P={class:"workflow-toolbar"},Q=["onDragstart"],R=E({__name:"WorkflowEditor",setup(s){const i=W(null),u=N(()=>{var a;return(a=i.value)==null?void 0:a.gui}),v=new C,{result:l,loading:b}=M(()=>A.create(v)),g=(a,c)=>{var e,p;(e=c.dataTransfer)==null||e.setData("type",a),(p=u.value)==null||p.dragstart(a,c)};return(a,c)=>t(b)?(o(),n(D,{key:0})):(o(),_("div",J,[t(l)?(o(),n(x,{key:0,ref_key:"canvasGui",ref:i,model:t(l)},null,8,["model"])):y("",!0),d(t(F),null,{default:r(()=>[w("div",P,[(o(!0),_(B,null,V(t(T).stages,e=>(o(),n(t(S),{key:e.typeName,placement:"top"},{title:r(()=>[d(t(q),null,{default:r(()=>[d(t(k),null,{default:r(()=>[f(m(e.title),1)]),_:2},1024),d(t(k),{keyboard:""},{default:r(()=>[f(m(e.key),1)]),_:2},1024)]),_:2},1024)]),content:r(()=>[f(m(e.description),1)]),default:r(()=>[w("span",{draggable:"true",onDragstart:p=>g(e.typeName,p)},[(o(),n(G(e.icon),{width:"18",height:"18",class:"toolbar-item"}))],40,Q)]),_:2},1024))),128)),d(t(I),{type:"vertical"}),t(l)?(o(),n(h,{key:0,model:t(l),disabled:void 0,type:"primary"},null,8,["model"])):y("",!0)])]),_:1})]))}});const vt=L(R,[["__scopeId","data-v-4a26884a"]]);export{vt as default};
//# sourceMappingURL=WorkflowEditor.5eaceb8a.js.map
